﻿// Main form
//    for moraMP4fix_for_NW-A860
//
// Copyright(C) 2014 Sota. All rights reserved.

using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Windows.Forms;
using System.IO;

namespace moraMP4fix_for_NW_A860
{
    public partial class Form1 : Form
    {
        /// <summary>
        /// Constructor
        /// </summary>
        public Form1()
        {
            InitializeComponent();
        }

        /// <summary>
        /// Allow drag & drop
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void Form1TextBox1DragEnter(object sender, DragEventArgs e)
        {
            if (e.Data.GetDataPresent(DataFormats.FileDrop))
            {
                e.Effect = DragDropEffects.Copy;    // allow copy
            }
        }

        /// <summary>
        /// Accept drop event
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void Form1TextBox1DragDrop(object sender, DragEventArgs e)
        {
            // Get dropped file list
            string[] dropFiles = (string[])e.Data.GetData(DataFormats.FileDrop);

            // Process each file
            FileProcessing processing = new FileProcessing();
            int modify = 0;
            bool error = false;
            foreach (string file in dropFiles)
            {
                bool modified;
                error = processing.ProcessOneFile(file, this, out modified);
                if (!error && modified)
                {
                    modify++;
                }
                if (error)
                {
                    break;
                }
            }

            if (error)
            {
                ShowMessage(global::moraMP4fix_for_NW_A860.Properties.Resources.AbortMessage);
            }
            else
            {
                ShowMessage(global::moraMP4fix_for_NW_A860.Properties.Resources.DoneMessage);
            }
            ShowMessage(string.Format(global::moraMP4fix_for_NW_A860.Properties.Resources.DoneFiles, dropFiles.Count(), modify));
            ShowMessage("-----------------------------------");
        }

        /// <summary>
        /// Show text in TextBox
        /// </summary>
        /// <param name="text">Text string</param>
        public void ShowMessage(string text)
        {
            textBox1.AppendText(text);
            textBox1.AppendText("\r\n");
        }

        /// <summary>
        /// Show error message in TextBox
        /// </summary>
        /// <param name="message">Error message string</param>
        /// <param name="e">Exception</param>
        public void ShowErrorMessage(string message, Exception e)
        {
            ShowMessage(message);
            if (e != null)
            {
                StringReader reader = new StringReader(e.ToString());
                ShowMessage(global::moraMP4fix_for_NW_A860.Properties.Resources.Reason + reader.ReadLine());
            }
        }

        /// <summary>
        /// Get whether Make-Backup is chekked
        /// </summary>
        /// <retunrs>true=chekked</retunrs>
        public bool GetBackupFileChecked()
        {
            return checkBox1.Checked;
        }

        /// <summary>
        /// About menu event
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void AboutMenuItem_Click(object sender, EventArgs e)
        {
            AboutForm form = new AboutForm();
            form.StartPosition = FormStartPosition.CenterParent;
            form.ShowDialog(this);
            form.Dispose();
        }

        /// <summary>
        /// Help-Index menu event
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void HelpIndexMenuItem_Click(object sender, EventArgs e)
        {
            Help.ShowHelp(this, "moraMP4fix_for_NW-A860.chm");
        }

        /// <summary>
        /// Exit menu event
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void ExitMenuItem_Click(object sender, EventArgs e)
        {
            this.Close();
        }

    }
}
